@@ -4,10 +4,11 @@ from collections import OrderedDict
 from os.path import join
 from typing import Any, Dict, List, Optional, Tuple
 
-from hdx.data.hdxobject import HDXObject, HDXObjectUpperBound
-from hdx.hdx_configuration import Configuration
 from hdx.utilities.downloader import Download
 
+from hdx.api.configuration import Configuration
+from hdx.data.hdxobject import HDXObject
+
 logger = logging.getLogger(__name__)
 
 
@@ -98,7 +99,9 @@ class Vocabulary(HDXObject):
         Returns:
             Optional[Vocabulary]: Vocabulary object if successful read, None if not
         """
-        return cls._read_from_hdx_class("vocabulary", identifier, configuration)
+        return cls._read_from_hdx_class(
+            "vocabulary", identifier, configuration
+        )
 
     @staticmethod
     def get_all_vocabularies(
@@ -115,10 +118,14 @@ class Vocabulary(HDXObject):
         """
 
         vocabulary = Vocabulary(configuration=configuration)
-        vocabulary["id"] = "all vocabulary names"  # only for error message if produced
+        vocabulary[
+            "id"
+        ] = "all vocabulary names"  # only for error message if produced
         vocabularies = list()
         for vocabularydict in vocabulary._write_to_hdx("list", {}):
-            vocabularies.append(Vocabulary(vocabularydict, configuration=configuration))
+            vocabularies.append(
+                Vocabulary(vocabularydict, configuration=configuration)
+            )
         return vocabularies
 
     def check_required_fields(self, ignore_fields: List[str] = list()) -> None:
@@ -147,7 +154,9 @@ class Vocabulary(HDXObject):
         Returns:
             None
         """
-        self._create_in_hdx("vocabulary", "id", "name", force_active=False, **kwargs)
+        self._create_in_hdx(
+            "vocabulary", "id", "name", force_active=False, **kwargs
+        )
 
     def delete_from_hdx(self, empty: bool = True) -> None:
         """Deletes a vocabulary from HDX. First tags are removed then vocabulary is deleted.
@@ -232,7 +241,9 @@ class Vocabulary(HDXObject):
 
     @classmethod
     def _read_approved_tags(
-        cls, url: Optional[str] = None, configuration: Optional[Configuration] = None
+        cls,
+        url: Optional[str] = None,
+        configuration: Optional[Configuration] = None,
     ) -> List[str]:
         """
         Read approved tags
@@ -255,7 +266,9 @@ class Vocabulary(HDXObject):
 
     @classmethod
     def create_approved_vocabulary(
-        cls, url: Optional[str] = None, configuration: Optional[Configuration] = None
+        cls,
+        url: Optional[str] = None,
+        configuration: Optional[Configuration] = None,
     ) -> "Vocabulary":
         """
         Create the HDX approved vocabulary
@@ -279,7 +292,9 @@ class Vocabulary(HDXObject):
 
     @classmethod
     def update_approved_vocabulary(
-        cls, url: Optional[str] = None, configuration: Optional[Configuration] = None
+        cls,
+        url: Optional[str] = None,
+        configuration: Optional[Configuration] = None,
     ) -> "Vocabulary":
         """
         Update the HDX approved vocabulary
@@ -320,7 +335,9 @@ class Vocabulary(HDXObject):
         vocabulary.delete_from_hdx()
 
     @classmethod
-    def approved_tags(cls, configuration: Optional[Configuration] = None) -> List[str]:
+    def approved_tags(
+        cls, configuration: Optional[Configuration] = None
+    ) -> List[str]:
         """
         Return list of approved tags
 
@@ -332,7 +349,9 @@ class Vocabulary(HDXObject):
         """
         return [
             x["name"]
-            for x in cls.get_approved_vocabulary(configuration=configuration)["tags"]
+            for x in cls.get_approved_vocabulary(configuration=configuration)[
+                "tags"
+            ]
         ]
 
     @classmethod
@@ -376,7 +395,9 @@ class Vocabulary(HDXObject):
         if not cls._tags_dict:
             if configuration is None:
                 configuration = Configuration.read()
-            with Download(full_agent=configuration.get_user_agent()) as downloader:
+            with Download(
+                full_agent=configuration.get_user_agent()
+            ) as downloader:
                 if url is None:
                     url = configuration["tags_mapping_url"]
                 cls._tags_dict = downloader.download_tabular_rows_as_dicts(
@@ -509,12 +530,12 @@ class Vocabulary(HDXObject):
 
     @classmethod
     def add_mapped_tag(
-        cls, hdxobject: HDXObjectUpperBound, tag: str, log_deleted: bool = True
+        cls, hdxobject: HDXObject, tag: str, log_deleted: bool = True
     ) -> Tuple[List[str], List[str]]:
         """Add a tag to an HDX object that has tags
 
         Args:
-            hdxobject (T <= HDXObject): HDX object such as dataset
+            hdxobject (HDXObject): HDX object such as dataset
             tag (str): Tag to add
             log_deleted (bool): Whether to log informational messages about deleted tags. Defaults to True.
 
@@ -525,12 +546,15 @@ class Vocabulary(HDXObject):
 
     @classmethod
     def add_mapped_tags(
-        cls, hdxobject: HDXObjectUpperBound, tags: List[str], log_deleted: bool = True
+        cls,
+        hdxobject: HDXObject,
+        tags: List[str],
+        log_deleted: bool = True,
     ) -> Tuple[List[str], List[str]]:
         """Add a list of tag to an HDX object that has tags
 
         Args:
-            hdxobject (T <= HDXObject): HDX object such as dataset
+            hdxobject (HDXObject): HDX object such as dataset
             tags (List[str]): List of tags to add
             log_deleted (bool): Whether to log informational messages about deleted tags. Defaults to True.
 
@@ -538,11 +562,15 @@ class Vocabulary(HDXObject):
             Tuple[List[str], List[str]]: Tuple containing list of added tags and list of deleted tags and tags not added
         """
         new_tags, deleted_tags = cls.get_mapped_tags(
-            tags, log_deleted=log_deleted, configuration=hdxobject.configuration
+            tags,
+            log_deleted=log_deleted,
+            configuration=hdxobject.configuration,
         )
         added_tags = hdxobject._add_tags(
             new_tags,
-            cls.get_approved_vocabulary(configuration=hdxobject.configuration)["id"],
+            cls.get_approved_vocabulary(configuration=hdxobject.configuration)[
+                "id"
+            ],
         )
         unadded_tags = [x for x in new_tags if x not in added_tags]
         unadded_tags.extend(deleted_tags)
@@ -550,12 +578,12 @@ class Vocabulary(HDXObject):
 
     @classmethod
     def clean_tags(
-        cls, hdxobject: HDXObjectUpperBound, log_deleted: bool = True
+        cls, hdxobject: HDXObject, log_deleted: bool = True
     ) -> Tuple[List[str], List[str]]:
         """Clean tags in an HDX object according to tags cleanup spreadsheet
 
         Args:
-            hdxobject (T <= HDXObject): HDX object such as dataset
+            hdxobject (HDXObject): HDX object such as dataset
             log_deleted (bool): Whether to log informational messages about deleted tags. Defaults to True.
 
         Returns:
